import { logger } from "../log.js";
import { getLevel } from "../admin.js";
import { spurdo } from "../spurdo.js";

const tgapi = require("node-telegram-bot-api")
  , EventEmitter = require("events").EventEmitter
  , util = require("util");

export class tg {
  constructor(options) {
    EventEmitter.call(this);
    this.options = options || {};
    this.token = options.token || null;
    this.options.polling = options.polling || true;
    this.client = new tgapi(this.options.token, this.options);

    this.server = {
      channel: new Map(),
      user: new Map(),
      me: {
        nickname: "Uwe"
      },
      spurdo: false
    };

    this.client.on("message", msg => {
      if (!this.server.user.has(msg.from.first_name))
        this.server.user.set(msg.from.username || msg.from.first_name, {
          nick: msg.from.first_name,
          username: msg.from.username,
          account: msg.from.id.toString(),
          prefix: `${msg.from.username}!${msg.from.id.toString()}`,
          id: msg.from.id
        });

      if (msg.date >= (~~(Date.now() / 1000) - 10) && msg.text !== undefined)
        this.emit("data", ["message", this.reply(msg)]);
    });
  }
  send(id, msg) {
    this.client.sendMessage(id, msg, { parse_mode: "HTML" });
  }
  reply(tmp) {
    return {
      type: "tg",
      network: "Telegram",
      channel: tmp.chat.title,
      channelid: tmp.chat.id,
      user: {
        prefix: `${tmp.from.username}!${tmp.from.id}`,
        nick: tmp.from.first_name,
        username: tmp.from.username,
        account: tmp.from.id.toString(),
        level: getLevel("Telegram", {
          prefix: `${tmp.from.username}!${tmp.from.id}`,
          nick: tmp.from.first_name,
          username: tmp.from.username,
          account: tmp.from.id.toString()
        })
      },
      self: this.server,
      message: tmp.text,
      time: tmp.date,
      raw: tmp,
      reply: msg => this.send(tmp.chat.id, this.format(msg)),
      replyAction: msg => this.send(tmp.chat.id, this.format(`Uwe ${msg}`)),
      replyNotice: msg => this.send(tmp.chat.id, this.format(msg)),
      _user: this.server.user
    };
  }
  format(msg) {
    if(this.server.spurdo)
      msg = spurdo(msg);
    return msg.toString()
      .replace("<", "&lt;")
      .replace(">", "&gt;")
      .replace(/\[b\](.*?)\[\/b\]/g, "<b>$1</b>") // bold
      .replace(/\[i\](.*?)\[\/i\]/g, "<i>$1</i>") // italic
      .replace(/\[color=(.*?)](.*?)\[\/color\]/g, "$2")
    ;
  }
}
util.inherits(tg, EventEmitter);